==> haskell-system-fileio-0.3.16.4-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-fileio
version:              0.3.16.4
visibility:           public
id:                   system-fileio-0.3.16.4-DLa7NtYf04M7fOfk3HhaGk
key:                  system-fileio-0.3.16.4-DLa7NtYf04M7fOfk3HhaGk
license:              MIT
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  7e3638e072c5ebe3a11b975c34b2634c
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-8.10.1/site-local/system-fileio-0.3.16.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/system-fileio-0.3.16.4
hs-libraries:         HSsystem-fileio-0.3.16.4-DLa7NtYf04M7fOfk3HhaGk
depends:
    base-4.14.0.0 bytestring-0.10.10.0
    system-filepath-0.4.14-1w89YoeSFBzIMRWXlYxf6v text-1.2.3.2
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.4-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-fileio
version:              0.3.16.4
visibility:           public
id:                   system-fileio-0.3.16.4-FaP3cpUQGVj2iQ0kc3Fwn5
key:                  system-fileio-0.3.16.4-FaP3cpUQGVj2iQ0kc3Fwn5
license:              MIT
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  387e49e301315a942dc97ad59e35d85d
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-8.10.2/site-local/system-fileio-0.3.16.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/system-fileio-0.3.16.4
hs-libraries:         HSsystem-fileio-0.3.16.4-FaP3cpUQGVj2iQ0kc3Fwn5
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    system-filepath-0.4.14-CeIOvncNStx6Ny7AcSXbYP text-1.2.3.2
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
